.. highlight:: shell

============
Installation
============


..
  Stable release
  --------------

  To install taperable-helix, run this command in your terminal:
  
  .. code-block:: console
  
      $ pip install taperable-helix
  
  This is the preferred method to install taperable_helix, as it will always install the most recent stable release.
  
  If you don't have `pip`_ installed, this `Python installation guide`_ can guide
  you through the process.
  
  .. _pip: https://pip.pypa.io
  .. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/
  
Test release from testpypi
--------------------------

To install taperable-helix from testpypi, run this command in your terminal:

.. code-block:: console

   $ pip install --index-url https://test.pypi.org/simple/ taperable-helix

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for taperable_helix can be downloaded from the `Github repo`_.

..
  You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/winksaville/py-taperable-helix taperable-helix
    $ cd taperable-helix

..
  Or download the `tarball`_:
  
  .. code-block:: console
  
      $ curl -OJL https://github.com/winksaville/taperable_helix/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install

Or if you want to install in editable mode for development:

.. code-block:: console

    $ pip install -e . 

Uninstall
---------

.. code-block:: console

    $ pip uninstall taperable-helix


.. _Github repo: https://github.com/winksaville/taperable_helix
..
   .. _tarball: https://github.com/winksaville/taperable_helix/tarball/master
